import React from "react";
import domHelper from "./DomHelper";
import { findDOMNode } from "react-dom";
// Is left click
function isLeftClick(event) {
    return (event === null || event === void 0 ? void 0 : event.button) === 0;
}
function isModifiedEvent(event) {
    return !!(event.metaKey || event.altKey || event.ctrlKey || (event === null || event === void 0 ? void 0 : event.shiftKey));
}
var getRefTarget = function (ref) {
    return ref && ("current" in ref ? ref.current : ref);
};
var getDomNode = function (elementOrRef) {
    var Element = (elementOrRef === null || elementOrRef === void 0 ? void 0 : elementOrRef.root) || (elementOrRef === null || elementOrRef === void 0 ? void 0 : elementOrRef.child) || getRefTarget(elementOrRef);
    return findDOMNode(Element);
};
var overlayClose = function (onCloseOverlay, _a) {
    var triggerTarget = _a.triggerTarget, overlayTarget = _a.overlayTarget, disabled = _a.disabled;
    var handleDocumentOnClick = React.useCallback(function (event) {
        var triggerElement = getDomNode(triggerTarget);
        var overlayElement = getDomNode(overlayTarget);
        // check if the clicked is the trigger element;
        if (triggerElement && domHelper.contains(triggerElement, event === null || event === void 0 ? void 0 : event.target)) {
            return;
        }
        // check if the clicked is the overlay element
        if (overlayElement && domHelper.contains(overlayElement, event === null || event === void 0 ? void 0 : event.target)) {
            return;
        }
        if (isModifiedEvent(event) || !isLeftClick(event)) {
            return;
        }
        onCloseOverlay === null || onCloseOverlay === void 0 ? void 0 : onCloseOverlay(event);
    }, [onCloseOverlay, triggerTarget, overlayTarget]);
    React.useEffect(function () {
        var target = getDomNode(triggerTarget);
        if (disabled || !target)
            return;
        var doc = domHelper.ownerDocument(target);
        var onClickDocument = domHelper.on(doc, "click", handleDocumentOnClick, true);
        return function () {
            onClickDocument === null || onClickDocument === void 0 ? void 0 : onClickDocument.off();
        };
    }, [disabled, triggerTarget, handleDocumentOnClick]);
};
export default overlayClose;
