"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _DomHelper = _interopRequireDefault(require("./DomHelper"));

var _reactDom = require("react-dom");

// Is left click
function isLeftClick(event) {
  return (event === null || event === void 0 ? void 0 : event.button) === 0;
}

function isModifiedEvent(event) {
  return !!(event.metaKey || event.altKey || event.ctrlKey || event !== null && event !== void 0 && event.shiftKey);
}

var getRefTarget = function getRefTarget(ref) {
  return ref && ("current" in ref ? ref.current : ref);
};

var getDomNode = function getDomNode(elementOrRef) {
  var Element = (elementOrRef === null || elementOrRef === void 0 ? void 0 : elementOrRef.root) || (elementOrRef === null || elementOrRef === void 0 ? void 0 : elementOrRef.child) || getRefTarget(elementOrRef);
  return (0, _reactDom.findDOMNode)(Element);
};

var overlayClose = function overlayClose(onCloseOverlay, _ref) {
  var triggerTarget = _ref.triggerTarget,
      overlayTarget = _ref.overlayTarget,
      disabled = _ref.disabled;

  var handleDocumentOnClick = _react.default.useCallback(function (event) {
    var triggerElement = getDomNode(triggerTarget);
    var overlayElement = getDomNode(overlayTarget); // check if the clicked is the trigger element;

    if (triggerElement && _DomHelper.default.contains(triggerElement, event === null || event === void 0 ? void 0 : event.target)) {
      return;
    } // check if the clicked is the overlay element


    if (overlayElement && _DomHelper.default.contains(overlayElement, event === null || event === void 0 ? void 0 : event.target)) {
      return;
    }

    if (isModifiedEvent(event) || !isLeftClick(event)) {
      return;
    }

    onCloseOverlay === null || onCloseOverlay === void 0 ? void 0 : onCloseOverlay(event);
  }, [onCloseOverlay, triggerTarget, overlayTarget]);

  _react.default.useEffect(function () {
    var target = getDomNode(triggerTarget);
    if (disabled || !target) return;

    var doc = _DomHelper.default.ownerDocument(target);

    var onClickDocument = _DomHelper.default.on(doc, "click", handleDocumentOnClick, true);

    return function () {
      onClickDocument === null || onClickDocument === void 0 ? void 0 : onClickDocument.off();
    };
  }, [disabled, triggerTarget, handleDocumentOnClick]);
};

var _default = overlayClose;
exports.default = _default;